==> quanyi-center-api-1.1.25-merge-20240717.062821-41-sources.jar: cn/com/duiba/quanyi/center/api/param/order/GoodsOrderEsSearchParam.java <==
package cn.com.duiba.quanyi.center.api.param.order;

import cn.com.duiba.quanyi.center.api.param.PageQuery;
import lombok.Data;
import lombok.EqualsAndHashCode;
import lombok.ToString;

import javax.validation.constraints.NotNull;
import java.util.Date;
import java.util.List;

/**
 * @author xuzhigang
 * @date 2024/6/28 10:39
 **/
@Data
@ToString(callSuper = true)
@EqualsAndHashCode(callSuper = true)
public class GoodsOrderEsSearchParam extends PageQuery {
    private static final long serialVersionUID = 8958867091102712341L;

    /**
     * 活动类型
     * 对应页面tab
     *  api供货 [7]
     *  兑吧卡密 [2,6]
     *  活动类 [1,3,4,5,8,9,10,12,13,14,15,16,17]
     *  车主商城 [11, 18]
     * @see cn.com.duiba.quanyi.center.api.enums.activity.BizActTypeEnum
     */
    private List<Integer> activityTypeList;

    /**
     * 订单创建时间开始时间
     */
    private Date startTime;

    /**
     * 订单创建时间结束时间
     */
    private Date endTime;

    /**
     * 交易单号
     */
    private String goodsOrderNo;

    /**
     * 商品名称
     */
    private String goodsName;

    /**
     * 活动名称
     */
    private String activityName;

    /**
     * 手机号
     */
    private String phoneNumber;

    /**
     * 订单状态
     * @see cn.com.duiba.quanyi.center.api.enums.goods.GoodsOrderStatusEnum
     */
    private Integer orderStatus;

    /**
     * 券码
     */
    private String couponCode;

    /**
     * 券链接
     */
    private String couponLink;

    /**
     * 支付单号
     */
    private String payOrderNo;

    /**
     * 对接方
     */
    private String partnerName;

    /**
     * 对接id
     */
    private Long apiJointId;

    /**
     * 客户订单号
     */
    private String thirdOrderId;

    /**
     * 兑吧单号
     */
    private String mainOrderNum;

    /**
     * 车主商城订单号
     */
    private String mallOrderNo;

    /**
     * 商品库spuId
     */
    private Long spuId;

    /**
     * 调用单号
     */
    private String outBizNo;
}

==> quanyi-center-api-1.1.44-merge-20240822.091331-57-sources.jar: cn/com/duiba/quanyi/center/api/param/order/GoodsOrderEsSearchParam.java <==
package cn.com.duiba.quanyi.center.api.param.order;

import cn.com.duiba.quanyi.center.api.enums.api.ApiSpecTypeEnum;
import cn.com.duiba.quanyi.center.api.param.PageQuery;
import lombok.Data;
import lombok.EqualsAndHashCode;
import lombok.ToString;

import java.util.Date;
import java.util.List;

/**
 * @author xuzhigang
 * @date 2024/6/28 10:39
 **/
@Data
@ToString(callSuper = true)
@EqualsAndHashCode(callSuper = true)
public class GoodsOrderEsSearchParam extends PageQuery {
    private static final long serialVersionUID = 8958867091102712341L;

    /**
     * 活动类型
     * 对应页面tab
     *  api供货 [7]
     *  兑吧卡密 [2,6]
     *  活动类 [1,3,4,5,8,9,10,12,13,14,15,16,17]
     *  车主商城 [11, 18]
     * @see cn.com.duiba.quanyi.center.api.enums.activity.BizActTypeEnum
     */
    private List<Integer> activityTypeList;

    /**
     * 订单状态集合
     * @see cn.com.duiba.quanyi.center.api.enums.goods.GoodsOrderStatusEnum
     */
    private List<Integer> orderStatusList;

    /**
     * 订单创建时间开始时间
     */
    private Date startTime;

    /**
     * 订单创建时间结束时间
     */
    private Date endTime;

    /**
     * 交易单号
     */
    private String goodsOrderNo;

    /**
     * 商品名称
     */
    private String goodsName;

    /**
     * 活动id
     * tb_activity.id
     */
    private Long activityId;

    /**
     * 活动名称
     */
    private String activityName;

    /**
     * 手机号
     */
    private String phoneNumber;

    /**
     * 订单状态
     * @see cn.com.duiba.quanyi.center.api.enums.goods.GoodsOrderStatusEnum
     */
    private Integer orderStatus;

    /**
     * 券码
     */
    private String couponCode;

    /**
     * 券链接
     */
    private String couponLink;

    /**
     * 支付单号
     */
    private String payOrderNo;

    /**
     * 对接方
     */
    private String partnerName;

    /**
     * 对接id
     */
    private Long apiJointId;

    /**
     * 客户订单号
     */
    private String thirdOrderId;

    /**
     * 兑吧单号
     */
    private String mainOrderNum;

    /**
     * 车主商城订单号
     */
    private String mallOrderNo;

    /**
     * 商品库spuId
     */
    private Long spuId;

    /**
     * 奖品id
     */
    private Long prizeId;

    /**
     * 奖品idList
     */
    private List<Long> prizeIdList;

    /**
     * 调用单号
     */
    private String outBizNo;

    /**
     * 商品类型
     *
     * @see ApiSpecTypeEnum#getType()
     */
    private Integer specType;
}
